# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-07-13 14:56
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('wagtailcore', '0028_merge'),
    ]

    operations = [
        migrations.CreateModel(
            name='RSSFeedsSettings',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('feed_app_label', models.CharField(blank=True, help_text=b'blog App whose Feed is to be generated', max_length=255, null=True)),
                ('feed_model_name', models.CharField(blank=True, help_text=b'Model to be used for feed generation', max_length=255, null=True)),
                ('feed_title', models.CharField(blank=True, help_text=b'Title of Feed', max_length=255, null=True)),
                ('feed_link', models.URLField(blank=True, help_text=b'link for Feed', max_length=255, null=True)),
                ('feed_description', models.CharField(blank=True, help_text=b'Description of field', max_length=255, null=True)),
                ('feed_author_email', models.EmailField(blank=True, help_text=b'Email of author', max_length=255, null=True)),
                ('feed_author_link', models.URLField(blank=True, help_text=b'Link of author', max_length=255, null=True)),
                ('feed_item_description_field', models.CharField(blank=True, help_text=b'Description field for feed item', max_length=255, null=True)),
                ('feed_item_content_field', models.CharField(blank=True, help_text=b'Content Field for feed item', max_length=255, null=True)),
                ('site', models.OneToOneField(editable=False, on_delete=django.db.models.deletion.CASCADE, to='wagtailcore.Site')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
